@@ -3,7 +3,7 @@ extern crate powershell_script;
 /// Print 'Hello' to console.
 fn main() {
     let hello = include_str!("script.ps1");
-    match powershell_script::run(hello, false) {
+    match powershell_script::run(hello) {
         Ok(output) => {
             eprint!("{}", output);
         }
